@@ -10,7 +10,7 @@ AMM_TIMES_PEG_TO_QUOTE_PRECISION_RATIO = (
     AMM_RESERVE_PRECISION * PEG_PRECISION / QUOTE_PRECISION
 )
 
-FULL_LIQUIDATION_RATIO = 500
-PARTIAL_LIQUIDATION_RATIO = 625
-
-MAX_LEVERAGE = 5
+# deprecated:
+# FULL_LIQUIDATION_RATIO = 500
+# PARTIAL_LIQUIDATION_RATIO = 625
+# MAX_LEVERAGE = 10
